unit Unit1;

{$WARN UNSAFE_TYPE OFF}

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  StdCtrls, ExtCtrls, Dialogs, EAppUpd, ComCtrls;


type
  TForm1 = class(TForm)
    EvAppUpdate1: TEvAppUpdate;
    StbInfo: TStatusBar;
    PanFundo: TPanel;
    MemInfo: TMemo;
    procedure EvAppUpdate1Error(Sender: TObject; Error: TEvUpdateError);
    procedure EvAppUpdate1NewVersion(Sender: TObject;
      Flags: TEvUpdateFlags; Info, Version: string; Size,
      Datetime: Integer; var Continue: Boolean);
    procedure EvAppUpdate1RequestLogout(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure EvAppUpdate1AppIsUpdated(Sender: TObject);
    procedure EvAppUpdate1DownloadProgress(Sender: TObject; BytesTotal,
      BytesReceived: Double);
  private
    function GetFileSize(const FileName: string): Integer;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses Unit2;

{$R *.dfm}


// FormShow
procedure TForm1.FormShow(Sender: TObject);
begin
  // verifica se existe alguma atualizao    
  EvAppUpdate1.Execute;
end;


// EvAppUpdate1AppIsUpdated
procedure TForm1.EvAppUpdate1AppIsUpdated(Sender: TObject);
begin
  // este evento  acionado se no for encontrada
  // nenhuma atualizao para a aplicao.

  ShowMessage('Nenhuma atualizao encontrada.');
end;


// EvAppUpdate1DownloadProgress
procedure TForm1.EvAppUpdate1DownloadProgress(Sender: TObject; BytesTotal, BytesReceived: Double);
var
  S: string;
begin
  // use este evento para informar ao usurio o progresso do download da atualizao

  S := FormatFloat('#0', (BytesReceived/BytesTotal)*100);
  StbInfo.SimpleText := 'Baixando atualizao: ' + S + '% concludo.';
end;


// EvAppUpdate1Error
procedure TForm1.EvAppUpdate1Error(Sender: TObject; Error: TEvUpdateError);
begin
  // este evento  acionado quando algum erro impede a atualizao

  case Error of
    ueInvalidURL: ShowMessage('O endereo no Servidor de atualizao no  vlido.');
    ueControlFile: ShowMessage('No foi possvel baixar o arquivo de controle da atualizao.');
    ueApplicationFile: ShowMessage('No foi possvel baixar o arquivo da atualizao.');
    ueInvalidControlFile: ShowMessage('O arquivo de controle da atualizao no  vlido.');
    ueUpdateError: ShowMessage('Um erro impediu a concluso do processo de atualizao.');
    ueAborted: ShowMessage('O processo de atualizao foi abortado pelo usurio.');
  end;
end;


// EvAppUpdate1NewVersion
procedure TForm1.EvAppUpdate1NewVersion(Sender: TObject; Flags: TEvUpdateFlags;
  Info, Version: String; Size, Datetime: Integer; var Continue: Boolean);
begin
  // informaes da aplicao atual
  Form2.EdtArquivo.Text := Application.ExeName;
  Form2.EdtVersaoAtual.Text := EvAppUpdate1.GetCurrentVersion;
  Form2.EdtDataAtual.Text := DateToStr(FileDateToDateTime(FileAge(Application.ExeName)));
  Form2.EdtTamanhoAtual.Text := FormatFloat('#,##0', GetFileSize(Application.ExeName)/1024) + 'KB';

  // informaes da NOVA aplicao. Observe que as variveis Version, Datetime, Size e Info foram
  // recebidas como parmetros do evento OnNewVersion
  Form2.EdtNovaVersao.Text := Version;
  Form2.EdtNovaData.Text := DateToStr(FileDateToDateTime(Datetime));
  Form2.EdtNovoTamanho.Text := FormatFloat('#,##0', Size/1024) + 'KB';
  Form2.MemInfo.Text := Info;

  // para aumentar a visibilidade vamos destacar o que foi alterado
  if ufVersion in Flags then
    Form2.EdtNovaVersao.Font.Style := [fsBold];
  if ufSize in Flags then
    Form2.EdtNovoTamanho.Font.Style := [fsBold];
  if ufDatetime in Flags then
    Form2.EdtNovaData.Font.Style := [fsBold];

  Continue := (Form2.ShowModal = mrOK);
  if Continue then
    ShowMessage('Voc pode continuar trabalhando normalmente enquanto a nova verso  baixada.')
end;


// EvAppUpdate1RequestLogout
procedure TForm1.EvAppUpdate1RequestLogout(Sender: TObject);
begin
  ShowMessage('A atualizao foi baixada com sucesso.'#13'Encerre esta aplicao para concluir o processo de atualizao.')
end;


// GetFileSize
function TForm1.GetFileSize(const FileName: string): Integer;
var
  Hnd: THandle;
  Data: TWin32FindData;
begin
  Result := -1;
  Hnd := FindFirstFile(PChar(FileName), Data);
  if Hnd <> INVALID_HANDLE_VALUE then
    begin
      Windows.FindClose(Hnd);
      if (Data.dwFileAttributes and FILE_ATTRIBUTE_DIRECTORY) = 0 then
        Result := Data.nFileSizeLow;
    end;
end;


end.
